iterationa matrix storing intermediate results of each iteration before
the entire program converges, including
"iter" iteration indicator
"error" mean squared error of random effects estimated from the current and
the previous iteration
"s2" estimated variance of residual error
"\(beta[1]\dots beta[p]\)" estimates of fixed effects
"\(gamma[1]\dots gamma[m]\)" estimates of random effects
parma vector containing 5 elements: "iter", "error",
"s2", "beta" and "df"
"iter" the number of iterations required by program to stop
"error" mean square error of random effect estimated from the last iteration
before the program stops
"s2" estimated variance of residual error
"beta" estimate of fixed effect
"df" the effective degree of freedom from total random effects
blupa matrix containing 4 columns: "gamma", "vg",
"wald" and "p_wald"
"gamma" estimate of random effect
"vg" estimated variance of random effect
"wald" Wald statistic calculated as \(\gamma^2\)/\(\Phi\)
"p_wald" the p-value of Wald statistic following Chi-squared
distribution with 1 degree of freedom